'use strict';

const compilerSfc = require('@vue/compiler-sfc');
const MagicString = require('magic-string');
const path = require('path');

const scriptTemplate = (name, lang) => {
  return `<script ${lang ? `lang="${lang}"` : ""}>
import { defineComponent } from 'vue'
export default defineComponent({
  name: '${name}',
})
<\/script>
`;
};
const getCode = (code, name, lang) => {
  let s;
  const str = () => s || (s = new MagicString(code));
  if (name) {
    str().appendLeft(0, scriptTemplate(name, lang));
  }
  return {
    map: str().generateMap(),
    code: str().toString()
  };
};
function supportVueSetupName(code, id, strategy) {
  const { descriptor } = compilerSfc.parse(code, { ignoreEmpty: false });
  let lang = "";
  if (!descriptor.script && descriptor.scriptSetup) {
    const result = compilerSfc.compileScript(descriptor, { id });
    const name = result.attrs.name;
    lang = result.attrs.lang;
    if (name) {
      return getCode(code, name, lang);
    }
  }
  if (strategy) {
    switch (strategy) {
      case "dir":
        return getCode(code, path.basename(path.dirname(id)), lang);
      case "file":
        return getCode(code, path.basename(id).replace(path.extname(id), ""), lang);
    }
  }
  return null;
}
const index = (options = {}) => {
  const { enable = true, dirs, strategy = void 0 } = options;
  const newDirs = dirs?.map((value) => {
    return path.resolve(value);
  });
  return {
    name: "vite:vue-setup-name",
    enforce: "pre",
    async transform(code, id) {
      if (!/\.vue$/.test(id)) {
        return null;
      }
      const ok = newDirs?.some((value) => {
        return id.indexOf(value) === 0;
      });
      if (ok === false) {
        return null;
      }
      if (enable) {
        return supportVueSetupName.call(this, code, id, strategy);
      }
      return null;
    }
  };
};

module.exports = index;
